View source: R/perspective-shiny.R
| psp_export | R Documentation |
Requests data export from the current Perspective view. The result is
delivered asynchronously to input$<outputId>_export.
psp_export(
proxy,
format = c("json", "csv", "columns", "arrow"),
start_row = NULL,
end_row = NULL,
start_col = NULL,
end_col = NULL
)
proxy |
A |
format |
Export format: |
start_row |
Optional single numeric value specifying the first row (0-based) to include in the export. |
end_row |
Optional single numeric value specifying the row (0-based, exclusive) at which to stop. |
start_col |
Optional single numeric value specifying the first column (0-based) to include. |
end_col |
Optional single numeric value specifying the column (0-based, exclusive) at which to stop. |
The proxy object (invisibly), for chaining.
if (interactive()) {
proxy <- perspectiveProxy(session, "viewer")
psp_export(proxy, format = "csv")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.