Skip to contents

Removes rows matching the given primary-key values from an indexed Perspective table. The table must have been created with an index column (see perspective).

Usage

psp_remove(proxy, keys)

Arguments

proxy

A perspectiveProxy object.

keys

A vector of key values identifying the rows to remove.

Value

The proxy object (invisibly), for chaining.

Examples

if (interactive()) {
proxy <- perspectiveProxy(session, "viewer")
psp_remove(proxy, keys = c("row1", "row2"))
}