Removes rows matching the given primary-key values from an indexed
Perspective table. The table must have been created with an index
column (see perspective).
Arguments
- proxy
A
perspectiveProxyobject.- keys
A vector of key values identifying the rows to remove.
Examples
if (interactive()) {
proxy <- perspectiveProxy(session, "viewer")
psp_remove(proxy, keys = c("row1", "row2"))
}