View source: R/perspective-shiny.R
| psp_remove | R Documentation |
Removes rows matching the given primary-key values from an indexed
Perspective table. The table must have been created with an index
column (see perspective).
psp_remove(proxy, keys)
proxy |
A |
keys |
A vector of key values identifying the rows to remove. |
The proxy object (invisibly), for chaining.
if (interactive()) {
proxy <- perspectiveProxy(session, "viewer")
psp_remove(proxy, keys = c("row1", "row2"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.